@@ -4,17 +4,15 @@ from datetime import datetime
 from pydate import to_date
 
 
-class TestIsAfter(unittest.TestCase):
+class TestToDate(unittest.TestCase):
     def test_to_date_1(self):
         """
-        returns true if the first date is after the second one
         :return:
         """
-        self.assertEqual(to_date(537350400.0), datetime(1987, 1, 11))
+        self.assertEqual(to_date(537350400.0), datetime(1987, 1, 11, 8, 0))
 
     def test_to_date_2(self):
         """
-        returns true if the first date is after the second one
         :return:
         """
         with self.assertRaises(OverflowError):
